@@ -91,7 +91,8 @@ for example), set this to the full interpreter path."
   ;; Make sure there is no obsolete rpc running
   :set (lambda (var val)                ;
          (set-default var val)
-         (when (fboundp 'elpy-rpc-restart)
+         (when (and (fboundp 'elpy-rpc-restart)
+                    (not (autoloadp #'elpy-rpc-restart)))
            (elpy-rpc-restart)))
   :group 'elpy)
 
@@ -283,8 +284,7 @@ During the execution of BODY the following variables are available:
            (quit nil))
          (unless same-venv
            (if venv-was-activated
-               (pyvenv-activate (directory-file-name
-                                 current-environment))
+               (pyvenv-activate venv-was-activated)
              (pyvenv-deactivate)))
          (when venv-err
            (error venv-err))
@@ -369,8 +369,11 @@ binaries used to create the virtualenv."
       (kill-buffer elpy-venv-buffname-visible))
     (with-elpy-rpc-virtualenv-activated
      (cond
-      ((= 0 (call-process elpy-rpc-python-command nil nil nil
-                          "-m" "venv" "-h"))
+      ((and (= 0 (call-process elpy-rpc-python-command nil nil nil
+                              "-m" "venv" "-h"))
+           ;; see https://github.com/jorgenschaefer/elpy/issues/1756
+           (= 0 (call-process elpy-rpc-python-command nil nil nil
+                              "-m" "ensurepip" "-h")))
        (with-current-buffer (get-buffer-create elpy-venv-buffname)
          (insert (concat "Running '" elpy-rpc-python-command " -m venv "
                          rpc-venv-path "':\n\n"))
@@ -384,7 +387,7 @@ binaries used to create the virtualenv."
          (setq success (call-process "virtualenv" nil t t "-p"
                                      elpy-rpc-python-command rpc-venv-path))))
       (t
-       (error "Elpy necessitates the 'virtualenv' python package, please install it with `pip install virtualenv`"))))
+       (error "Elpy needs the 'virtualenv' or 'venv' python packages to create its virtualenv. Please install one of them or disable the dedicated virtualenv with `(setq elpy-rpc-virtualenv-path 'current)`"))))
     ;; warn us if something wrong happened
     (unless (= 0 success)
       (with-current-buffer elpy-venv-buffname
@@ -1048,6 +1051,19 @@ Returns a calltip string for the function call at point."
               success error)))
 
 
+(defun elpy-rpc-get-calltip-or-oneline-docstring (&optional success error)
+  "Call the get_calltip_or_oneline_doc API function.
+
+Returns a calltip string or a oneline docstring for the function call at point."
+  (when (< (buffer-size) elpy-rpc-ignored-buffer-size)
+    (elpy-rpc "get_calltip_or_oneline_docstring"
+              (list buffer-file-name
+                    (elpy-rpc--buffer-contents)
+                    (- (point)
+                       (point-min)))
+              success error)))
+
+
 (defun elpy-rpc-get-oneline-docstring (&optional success error)
   "Call the get_oneline_docstring API function.
 
