@@ -3,10 +3,16 @@
     (let ((major-mode 'not-python-mode))
       (should-error (elpy-mode)))))
 
+(ert-deftest elpy-mode-should-fail-when-elpy-not-activated ()
+  (elpy-testcase ()
+    (python-mode)
+    (should-error (elpy-mode))))
+
 (ert-deftest elpy-mode-should-run-buffer-init-on-start ()
   (elpy-testcase ()
     (python-mode)
     (mletf* ((buffer-init-called nil)
+             (elpy-enabled-p t)
              (elpy-modules-buffer-init
               ()
               (setq buffer-init-called t)))
@@ -17,6 +23,7 @@
 
 (ert-deftest elpy-mode-should-run-buffer-stop-on-stop ()
   (elpy-testcase ()
+    (elpy-enable)
     (python-mode)
     (mletf* ((buffer-stop-called nil)
              (elpy-modules-buffer-stop
